Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(617)

Unified Diff: chrome/common/chrome_notification_types.h

Issue 10353007: Extract a minimal subset of WebDialogUI/WebDialogDelegate from src/chrome -> src/ui/web_dialogs Base URL: http://src.chromium.org/svn/trunk/src/
Patch Set: Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/chrome_notification_types.h
===================================================================
--- chrome/common/chrome_notification_types.h (revision 135175)
+++ chrome/common/chrome_notification_types.h (working copy)
@@ -6,12 +6,12 @@
#define CHROME_COMMON_CHROME_NOTIFICATION_TYPES_H_
#pragma once
-#include "content/public/browser/notification_types.h"
+#include "ui/web_dialogs/web_dialog_notification_types.h"
namespace chrome {
enum NotificationType {
- NOTIFICATION_CHROME_START = content::NOTIFICATION_CONTENT_END,
+ NOTIFICATION_CHROME_START = web_dialogs::NOTIFICATION_WEB_DIALOGS_END,
// Browser-window ----------------------------------------------------------
@@ -1077,9 +1077,9 @@
NOTIFICATION_CONTENT_BLOCKED_STATE_CHANGED,
// Note:-
// Currently only Content and Chrome define and use notifications.
// Custom notifications not belonging to Content and Chrome should start
// from here.
NOTIFICATION_CHROME_END,
};
@@ -1077,9 +1077,9 @@
NOTIFICATION_CONTENT_BLOCKED_STATE_CHANGED,
// Note:-
- // Currently only Content and Chrome define and use notifications.
- // Custom notifications not belonging to Content and Chrome should start
- // from here.
+ // Currently only Content, Chrome and WebDialogs define and use notifications.
+ // Custom notifications not belonging to Content,
+ // Chrome and WebDialogs should start from here.
NOTIFICATION_CHROME_END,
};

Powered by Google App Engine
This is Rietveld 408576698